@@ -26,6 +26,7 @@ from agno.playground.schemas import (
     WorkflowSessionResponse,
     WorkflowsGetResponse,
 )
+from agno.run.response import RunEvent
 from agno.storage.agent.session import AgentSession
 from agno.storage.workflow.session import WorkflowSession
 from agno.utils.log import logger
@@ -58,6 +59,10 @@ def get_async_playground_router(
             provider = agent.model.provider or agent.model.__class__.__name__ if agent.model else ""
             model_id = agent.model.id if agent.model else None
 
+            # Create an agent_id if its not set on the agent
+            if agent.agent_id is None:
+                agent.set_agent_id()
+
             if provider and model_id:
                 provider = f"{provider} {model_id}"
             elif name and model_id:
@@ -95,17 +100,25 @@ def get_async_playground_router(
         audio: Optional[List[Audio]] = None,
         videos: Optional[List[Video]] = None,
     ) -> AsyncGenerator:
-        run_response = await agent.arun(
-            message,
-            images=images,
-            audio=audio,
-            videos=videos,
-            stream=True,
-            stream_intermediate_steps=True,
-        )
-        async for run_response_chunk in run_response:
-            run_response_chunk = cast(RunResponse, run_response_chunk)
-            yield run_response_chunk.to_json()
+        try:
+            run_response = await agent.arun(
+                message,
+                images=images,
+                audio=audio,
+                videos=videos,
+                stream=True,
+                stream_intermediate_steps=True,
+            )
+            async for run_response_chunk in run_response:
+                run_response_chunk = cast(RunResponse, run_response_chunk)
+                yield run_response_chunk.to_json()
+        except Exception as e:
+            error_response = RunResponse(
+                content=str(e),
+                event=RunEvent.run_error,
+            )
+            yield error_response.to_json()
+            return
 
     async def process_image(file: UploadFile) -> Image:
         content = file.file.read()
@@ -121,17 +134,12 @@ def get_async_playground_router(
         session_id: Optional[str] = Form(None),
         user_id: Optional[str] = Form(None),
         files: Optional[List[UploadFile]] = File(None),
-        image: Optional[UploadFile] = File(None),
     ):
         logger.debug(f"AgentRunRequest: {message} {session_id} {user_id} {agent_id}")
         agent = get_agent_by_id(agent_id, agents)
         if agent is None:
             raise HTTPException(status_code=404, detail="Agent not found")
 
-        if files:
-            if agent.knowledge is None:
-                raise HTTPException(status_code=404, detail="KnowledgeBase not found")
-
         if session_id is not None:
             logger.debug(f"Continuing session: {session_id}")
         else:
@@ -139,6 +147,7 @@ def get_async_playground_router(
 
         # Create a new instance of this agent
         new_agent_instance = agent.deep_copy(update={"session_id": session_id})
+        new_agent_instance.session_name = None
         if user_id is not None:
             new_agent_instance.user_id = user_id
 
@@ -147,62 +156,82 @@ def get_async_playground_router(
         else:
             new_agent_instance.monitoring = False
 
-        base64_image: Optional[Image] = None
-        if image:
-            base64_image = await process_image(image)
+        base64_images: List[Image] = []
 
         if files:
             for file in files:
-                if file.content_type == "application/pdf":
-                    from agno.document.reader.pdf_reader import PDFReader
-
-                    contents = await file.read()
-                    pdf_file = BytesIO(contents)
-                    pdf_file.name = file.filename
-                    file_content = PDFReader().read(pdf_file)
-                    if agent.knowledge is not None:
-                        agent.knowledge.load_documents(file_content)
-                elif file.content_type == "text/csv":
-                    from agno.document.reader.csv_reader import CSVReader
-
-                    contents = await file.read()
-                    csv_file = BytesIO(contents)
-                    csv_file.name = file.filename
-                    file_content = CSVReader().read(csv_file)
-                    if agent.knowledge is not None:
-                        agent.knowledge.load_documents(file_content)
-                elif file.content_type == "application/vnd.openxmlformats-officedocument.wordprocessingml.document":
-                    from agno.document.reader.docx_reader import DocxReader
-
-                    contents = await file.read()
-                    docx_file = BytesIO(contents)
-                    docx_file.name = file.filename
-                    file_content = DocxReader().read(docx_file)
-                    if agent.knowledge is not None:
-                        agent.knowledge.load_documents(file_content)
-                elif file.content_type == "text/plain":
-                    from agno.document.reader.text_reader import TextReader
-
-                    contents = await file.read()
-                    text_file = BytesIO(contents)
-                    text_file.name = file.filename
-                    file_content = TextReader().read(text_file)
-                    if agent.knowledge is not None:
-                        agent.knowledge.load_documents(file_content)
+                if file.content_type in ["image/png", "image/jpeg", "image/jpg", "image/webp"]:
+                    try:
+                        base64_image = await process_image(file)
+                        base64_images.append(base64_image)
+                    except Exception as e:
+                        logger.error(f"Error processing image {file.filename}: {e}")
+                        continue
                 else:
-                    raise HTTPException(status_code=400, detail="Unsupported file type")
+                    # Check for knowledge base before processing documents
+                    if new_agent_instance.knowledge is None:
+                        raise HTTPException(status_code=404, detail="KnowledgeBase not found")
+
+                    if file.content_type == "application/pdf":
+                        from agno.document.reader.pdf_reader import PDFReader
+
+                        contents = await file.read()
+                        pdf_file = BytesIO(contents)
+                        pdf_file.name = file.filename
+                        file_content = PDFReader().read(pdf_file)
+                        if new_agent_instance.knowledge is not None:
+                            new_agent_instance.knowledge.load_documents(file_content)
+                    elif file.content_type == "text/csv":
+                        from agno.document.reader.csv_reader import CSVReader
+
+                        contents = await file.read()
+                        csv_file = BytesIO(contents)
+                        csv_file.name = file.filename
+                        file_content = CSVReader().read(csv_file)
+                        if new_agent_instance.knowledge is not None:
+                            new_agent_instance.knowledge.load_documents(file_content)
+                    elif file.content_type == "application/vnd.openxmlformats-officedocument.wordprocessingml.document":
+                        from agno.document.reader.docx_reader import DocxReader
+
+                        contents = await file.read()
+                        docx_file = BytesIO(contents)
+                        docx_file.name = file.filename
+                        file_content = DocxReader().read(docx_file)
+                        if new_agent_instance.knowledge is not None:
+                            new_agent_instance.knowledge.load_documents(file_content)
+                    elif file.content_type == "text/plain":
+                        from agno.document.reader.text_reader import TextReader
+
+                        contents = await file.read()
+                        text_file = BytesIO(contents)
+                        text_file.name = file.filename
+                        file_content = TextReader().read(text_file)
+                        if new_agent_instance.knowledge is not None:
+                            new_agent_instance.knowledge.load_documents(file_content)
+
+                    elif file.content_type == "application/json":
+                        from agno.document.reader.json_reader import JSONReader
+
+                        contents = await file.read()
+                        json_file = BytesIO(contents)
+                        json_file.name = file.filename
+                        file_content = JSONReader().read(json_file)
+                        if new_agent_instance.knowledge is not None:
+                            new_agent_instance.knowledge.load_documents(file_content)
+                    else:
+                        raise HTTPException(status_code=400, detail="Unsupported file type")
 
         if stream:
             return StreamingResponse(
-                chat_response_streamer(new_agent_instance, message, images=[base64_image] if base64_image else None),
+                chat_response_streamer(new_agent_instance, message, images=base64_images if base64_images else None),
                 media_type="text/event-stream",
             )
         else:
             run_response = cast(
                 RunResponse,
                 await new_agent_instance.arun(
-                    message,
-                    images=[base64_image] if base64_image else None,
+                    message=message,
+                    images=base64_images if base64_images else None,
                     stream=False,
                 ),
             )
@@ -262,7 +291,7 @@ def get_async_playground_router(
             if session.session_id == session_id:
                 agent.session_id = session_id
                 agent.rename_session(body.name)
-                return JSONResponse(content={"message": f"successfully renamed agent {agent.name}"})
+                return JSONResponse(content={"message": f"successfully renamed session {session.session_id}"})
 
         return JSONResponse(status_code=404, content="Session not found.")
 
@@ -279,7 +308,7 @@ def get_async_playground_router(
         for session in all_agent_sessions:
             if session.session_id == session_id:
                 agent.delete_session(session_id)
-                return JSONResponse(content={"message": f"successfully deleted agent {agent.name}"})
+                return JSONResponse(content={"message": f"successfully deleted session {session_id}"})
 
         return JSONResponse(status_code=404, content="Session not found.")
 
