@@ -6,7 +6,7 @@ try:
     import lancedb
     import pyarrow as pa
 except ImportError:
-    raise ImportError("`lancedb` not installed.")
+    raise ImportError("`lancedb` not installed. Please install using `pip install lancedb`")
 
 from agno.document import Document
 from agno.embedder import Embedder
@@ -18,6 +18,25 @@ from agno.vectordb.search import SearchType
 
 
 class LanceDb(VectorDb):
+    """
+    LanceDb class for managing vector operations with LanceDb
+
+    Args:
+        uri: The URI of the LanceDB database.
+        table: The LanceDB table instance to use.
+        table_name: The name of the LanceDB table to use.
+        connection: The LanceDB connection to use.
+        api_key: The API key to use for the LanceDB connection.
+        embedder: The embedder to use when embedding the document contents.
+        search_type: The search type to use when searching for documents.
+        distance: The distance metric to use when searching for documents.
+        nprobes: The number of probes to use when searching for documents.
+        reranker: The reranker to use when reranking documents.
+        use_tantivy: Whether to use Tantivy for full text search.
+        on_bad_vectors: What to do if the vector is bad. One of "error", "drop", "fill", "null".
+        fill_value: The value to fill the vector with if on_bad_vectors is "fill".
+    """
+
     def __init__(
         self,
         uri: lancedb.URI = "/tmp/lancedb",
@@ -31,6 +50,8 @@ class LanceDb(VectorDb):
         nprobes: Optional[int] = None,
         reranker: Optional[Reranker] = None,
         use_tantivy: bool = True,
+        on_bad_vectors: Optional[str] = None,  # One of "error", "drop", "fill", "null".
+        fill_value: Optional[float] = None,  # Only used if on_bad_vectors is "fill"
     ):
         # Embedder for embedding the document contents
         if embedder is None:
@@ -84,10 +105,12 @@ class LanceDb(VectorDb):
 
         self.reranker: Optional[Reranker] = reranker
         self.nprobes: Optional[int] = nprobes
+        self.on_bad_vectors: Optional[str] = on_bad_vectors
+        self.fill_value: Optional[float] = fill_value
         self.fts_index_exists = False
         self.use_tantivy = use_tantivy
 
-        if self.use_tantivy:
+        if self.use_tantivy and (self.search_type in [SearchType.keyword, SearchType.hybrid]):
             try:
                 import tantivy  # noqa: F401
             except ImportError:
@@ -100,7 +123,7 @@ class LanceDb(VectorDb):
     def create(self) -> None:
         """Create the table if it does not exist."""
         if not self.exists():
-            self.connection = self._init_table()  # Connection update is needed
+            self.table = self._init_table()
 
     def _init_table(self) -> lancedb.db.LanceTable:
         schema = pa.schema(
@@ -128,11 +151,16 @@ class LanceDb(VectorDb):
         Args:
             document (Document): Document to validate
         """
-        if self.table is not None:
-            cleaned_content = document.content.replace("\x00", "\ufffd")
-            doc_id = md5(cleaned_content.encode()).hexdigest()
-            result = self.table.search().where(f"{self._id}='{doc_id}'").to_arrow()
-            return len(result) > 0
+        try:
+            if self.table is not None:
+                cleaned_content = document.content.replace("\x00", "\ufffd")
+                doc_id = md5(cleaned_content.encode()).hexdigest()
+                result = self.table.search().where(f"{self._id}='{doc_id}'").to_arrow()
+                return len(result) > 0
+        except Exception:
+            # Search sometimes fails with stale cache data, it means the doc doesn't exist
+            return False
+
         return False
 
     def insert(self, documents: List[Document], filters: Optional[Dict[str, Any]] = None) -> None:
@@ -176,7 +204,11 @@ class LanceDb(VectorDb):
             logger.debug("No new data to insert")
             return
 
-        self.table.add(data)
+        if self.on_bad_vectors is not None:
+            self.table.add(data, on_bad_vectors=self.on_bad_vectors, fill_value=self.fill_value)
+        else:
+            self.table.add(data)
+
         logger.debug(f"Inserted {len(data)} documents")
 
     def upsert(self, documents: List[Document], filters: Optional[Dict[str, Any]] = None) -> None:
@@ -326,4 +358,17 @@ class LanceDb(VectorDb):
         return False
 
     def name_exists(self, name: str) -> bool:
-        raise NotImplementedError
+        """Check if a document with the given name exists in the database"""
+        if self.table is None:
+            return False
+
+        try:
+            result = self.table.search().select(["payload"]).to_pandas()
+            # Convert the JSON strings in payload column to dictionaries
+            payloads = result["payload"].apply(json.loads)
+
+            # Check if the name exists in any of the payloads
+            return any(payload.get("name") == name for payload in payloads)
+        except Exception as e:
+            logger.error(f"Error checking name existence: {e}")
+            return False
